@@ -1,15 +1,6 @@
 from abc import ABC, abstractmethod
 from collections.abc import AsyncGenerator, Awaitable, Coroutine
-from typing import (
-    Any,
-    Callable,
-    Generic,
-    Optional,
-    TypeVar,
-    Union,
-    overload,
-    runtime_checkable,
-)
+from typing import Any, Callable, Generic, Optional, TypeVar, Union, overload, runtime_checkable
 
 from PIL import Image
 from reactivex import Observable
@@ -263,6 +254,8 @@ class CameraActivitySettings(TypedDict):
 
 CameraType = Literal["camera", "doorbell"]
 
+CameraFrameWorker = Literal["pillow", "sharp", "wasm"]
+
 
 class Camera(TypedDict):
     _id: str
@@ -286,9 +279,13 @@ class Camera(TypedDict):
     hasIntercom: bool
     hasPtz: bool
     sources: list[CameraInput]
+    frameWorker: Literal["pillow", "sharp", "wasm"]
 
 
 CameraPublicProperties = Literal[
+    "_id",
+    "nativeId",
+    "pluginId",
     "name",
     "disabled",
     "isCloud",
@@ -307,6 +304,7 @@ CameraPublicProperties = Literal[
     "hasIntercom",
     "hasPtz",
     "sources",
+    "frameWorker",
 ]
 
 PropertyValue = Union[
@@ -759,6 +757,7 @@ class CameraStateChangedObject(Generic[SV], dict[str, SV]):
 
 
 class CameraPropertyObservableObject(Generic[PV], dict[str, PV]):
+    property: str
     old_state: PV
     new_state: PV
 
